/*
 * Copyright (c) 2017 Goldman Sachs.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * and Eclipse Distribution License v. 1.0 which accompany this distribution.
 * The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
 * and the Eclipse Distribution License is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 */

package org.eclipse.collections.api.list.primitive;

import org.eclipse.collections.api.block.function.primitive.FloatToObjectFunction;
import org.eclipse.collections.api.block.predicate.primitive.FloatPredicate;
import org.eclipse.collections.api.list.ListIterable;
import org.eclipse.collections.api.ordered.primitive.ReversibleFloatIterable;

/**
 * This file was automatically generated from template file primitiveList.stg.
 *
 * @since 3.0.
 */
public interface FloatList extends ReversibleFloatIterable
{
    float get(int index);

    double dotProduct(FloatList list);

    int binarySearch(float value);

    int lastIndexOf(float value);

    @Override
    FloatList select(FloatPredicate predicate);

    @Override
    FloatList reject(FloatPredicate predicate);

    @Override
    <V> ListIterable<V> collect(FloatToObjectFunction<? extends V> function);

    /**
     * Follows the same general contract as {@link java.util.List#equals(Object)}.
     */
    @Override
    boolean equals(Object o);

    /**
     * Follows the same general contract as {@link java.util.List#hashCode()}.
     */
    @Override
    int hashCode();

    /**
     * Returns an immutable copy of this list. If the list is immutable, it returns itself.
     */
    ImmutableFloatList toImmutable();

    /**
     * @since 6.0.
     */
    @Override
    FloatList distinct();

    /**
     * @since 5.0.
     */
    @Override
    FloatList toReversed();

    /**
     * @see java.util.List#subList(int fromIndex, int toIndex)
     * @since 5.0.
     */
    FloatList subList(int fromIndex, int toIndex);
}
